<?php 
/**
 * $Desc
 *
 * @version    $Id$
 * @package    wpbase
 * @author     bigtheme Team <bigtheme@gmail.com, support@bigtheme.ir>
 * @copyright  Copyright (C) 2015 bigtheme.ir. All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * @website  http://www.bigtheme.ir
 * @support  http://www.bigtheme.ir
 */
class Newshopping_PBRUserLogin{

	/**
	 * @var boolean $ispopup 
	 */
	private $ispopup = true; 

	/**
	 * Constructor 
	 */
	public function __construct(){
		
		add_action('init', array($this,'setup'), 1000);
		add_action( 'wp_ajax_nopriv_pbrajaxlogin',  array($this,'ajaxDoLogin') );
		add_action( 'wp_ajax_nopriv_pbrajaxlostpass',  array($this,'doForgotPassword') );

	}


	/**
	 * process login function with ajax request
	 *
 	 * ouput Json Data with messsage and login status
	 */
	public function ajaxDoLogin(){
		// First check the nonce, if it fails the function will break
   		check_ajax_referer( 'ajax-pbr-login-nonce', 'security' );
   		$result = $this->doLogin($_POST['pbr_username'], $_POST['pbr_password'],  isset($_POST['remember']) ); 
   		
   		echo trim($result);
   		die();
	}


	/**
	 * process user login with username/password
	 *
	 * return Json Data with messsage and login status
	 */
	public function doLogin( $username, $password, $remember=false ){
		$info = array();
   		
   		$info['user_login'] = $username;
	    $info['user_password'] = $password;
	    $info['remember'] = $remember;
		
		$user_signon = wp_signon( $info, false );
	    if ( is_wp_error($user_signon) ){
			return json_encode(array('loggedin'=>false, 'message'=>__('Wrong username or password. Please try again!!!', 'newshopping')));
	    } else {
			wp_set_current_user($user_signon->ID); 
	        return json_encode(array('loggedin'=>true, 'message'=>__('Signin successful, redirecting...', 'newshopping')));
	    }
	}


	/**
	 * process user doForgotPassword with username/password
	 *
	 * return Json Data with messsage and login status
	 */	
	public function doForgotPassword(){
	 
		// First check the nonce, if it fails the function will break
	    check_ajax_referer( 'ajax-pbr-lostpassword-nonce', 'security' );
		
		global $wpdb;
		
		$account = $_POST['user_login'];
		
		if( empty( $account ) ) {
			$error = __( 'Enter an username or e-mail address.', 'newshopping' );
		} else {
			if(is_email( $account )) {
				if( email_exists($account) ) 
					$get_by = 'email';
				else	
					$error = __( 'There is no user registered with that email address.', 'newshopping' );			
			}
			else if (validate_username( $account )) {
				if( username_exists($account) ) 
					$get_by = 'login';
				else	
					$error = __( 'There is no user registered with that username.', 'newshopping' );				
			}
			else
				$error = __(  'Invalid username or e-mail address.', 'newshopping' );		
		}	
		
		if(empty ($error)) {
			$random_password = wp_generate_password();

			$user = get_user_by( $get_by, $account );
				
			$update_user = wp_update_user( array ( 'ID' => $user->ID, 'user_pass' => $random_password ) );
				
			if( $update_user ) {
				
				$from = get_option('admin_email'); // Set whatever you want like mail@yourdomain.com
				
				if(!(isset($from) && is_email($from))) {		
					$sitename = strtolower( $_SERVER['SERVER_NAME'] );
					if ( substr( $sitename, 0, 4 ) == 'www.' ) {
						$sitename = substr( $sitename, 4 );					
					}
					$from = 'do-not-reply@'.$sitename; 
				}
				
				$to = $user->user_email;
				$subject = __( 'Your new password', 'newshopping' );
				$sender = 'From: '.get_option('name').' <'.$from.'>' . "\r\n";
				
				$message = __( 'Your new password is: ', 'newshopping' ) .$random_password;
					
				$headers[] = 'MIME-Version: 1.0' . "\r\n";
				$headers[] = 'Content-type: text/html; charset=iso-8859-1' . "\r\n";
				$headers[] = "X-Mailer: PHP \r\n";
				$headers[] = $sender;
					
				$mail = wp_mail( $to, $subject, $message, $headers );
				if( $mail ) 
					$success = __( 'Check your email address for you new password.', 'newshopping' );
				else
					$error = __( 'System is unable to send you mail containg your new password.', 'newshopping' );						
			} else {
				$error =  __( 'Oops! Something went wrong while updating your account.', 'newshopping' );
			}
		}
	
		if( ! empty( $error ) )
			echo json_encode(array('loggedin'=>false, 'message'=> ($error)));
				
		if( ! empty( $success ) )
			echo json_encode(array('loggedin'=>false, 'message'=> $success ));	
		die();
	}


	/**
	 * add all actions will be called when user login.
	 */
	public function setup(){
		if ( !is_user_logged_in() ) {
			add_action('wp_footer', array( $this,'signin') );
		}
		add_action( 'pbr-login-button', array( $this, 'button' ) );

	}

	/**
	 * render link login or show greeting when user logined in
	 *
	 * @return String.
	 */
	public function button(){
		if ( !is_user_logged_in() ) {
			echo '<a href="#"  data-toggle="modal" data-target="#modalLoginForm" class="pbr-user-login">'.__( 'Login','newshopping' ).'</a>';
		}else {
			return $this->greetingContext();
		}
	}

	/**
	 * check if user not login that showing the form
	 */
	public function signin(){
		if ( !is_user_logged_in() ) {
 			return $this->form();
		}	
	}

	/**
	 * Display greeting words
	 */
	public function greeting(){
		$current_user = wp_get_current_user();
		$link = esc_url(wp_logout_url( home_url() ));
		printf('Greeting %s (%s)', $current_user->user_nicename, '<a href="'.$link.'" title="'.__( 'Logout', 'newshopping' ).'">'.__( 'Logout', 'newshopping' ).'</a>' );
	}

	/**
	 *
	 */
	public function greetingContext(){
		$current_user = wp_get_current_user();
		$link = esc_url(wp_logout_url( home_url() ));

		echo ' <div class="account-links dropdown">
				  <a href="#" class="dropdown-toggle"  id="dropdownMenu1" data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">
				    '.__( 'Howdy', 'newshopping').', '.$current_user->user_nicename.'
				    <span class="caret"></span>
				  </a>
				 <a class="signout" href="'.$link.'" title="'.__( 'Logout', 'newshopping' ).'">'.__( 'Logout', 'newshopping' ).'</a>
				<div class="dropdown-menu">';
				    $args = array(
                        'theme_location'  => 'accountmenu',
                        'container_class' => '',
                        'menu_class'      => 'myaccount-menu'
                    );
                    wp_nav_menu($args);
	 	     
		echo		  '</div>
				</div>';

	}

	/**
	 * render login form
	 */
	public function form(){
		    echo '
			    <div class="modal fade" id="modalLoginForm" tabindex="-1" role="dialog" aria-labelledby="modalLoginForm">
				      <div class="modal-dialog" role="document">
						<div class="modal-content"><div class="modal-body">';
			
			echo 		'	<div class="inner">
					    		<a href="'.esc_url(get_site_url()).'">
										<img class="img-responsive center-image" src="'.get_template_directory_uri().'/images/logo.png" alt="" >
								</a>
						   <div id="pbrloginform" class="form-wrapper"> <form class="login-form" action="' . $_SERVER['REQUEST_URI'] . '" method="post">
						     
						    	<p class="lead">'.__("Hello, Welcome Back!", 'newshopping').'</p>
							    <div class="form-group">
								    <input autocomplete="off" type="text" name="pbr_username" class="required form-control"  placeholder="'.__("Username",'newshopping').'" />
							    </div>
							    <div class="form-group">
								    <input autocomplete="off" type="password" class="password required form-control" placeholder="'.__("Password",'newshopping').'" name="pbr_password" >
							    </div>
							     <div class="form-group">
							   	 	<label for="pbr-user-remember" ><input type="checkbox" name="remember" id="pbr-user-remember" value="true"> '.__("Remember Me",'newshopping').'</label>
							    </div>
							    <div class="form-group">
							    	<input type="submit" class="btn btn-primary" name="submit" value="'.__("Log In",'newshopping').'"/>
							    	<input type="button" class="btn btn-default btn-cancel" name="cancel" value="'.__("Cancel",'newshopping').'"/>
							    </div>
					';
					    echo '<p><a href="#pbrlostpasswordform" class="toggle-links" title="'.__("Forgot Password",'newshopping').'">'.__("Lost Your Password?",'newshopping').'</a></p>';	
					    if(get_option('register_page_id')){ 
					    	echo "<p>".__('Dont not have an account?', 'newshopping' )." <a href='".esc_url(get_permalink( get_option('register_page_id') ))."' title='".__('Sign Up','newshopping')."'>".__('Sign Up', 'newshopping')."</a></p>";	
					    }
						    do_action('login_form');
						    wp_nonce_field('ajax-pbr-login-nonce', 'security');
		    echo '</form></div>';
		    echo '<div id="pbrlostpasswordform" class="form-wrapper">';
		    print $this->resetForm();
		   	echo '</div>';
		    echo '		</div></div></div>
					</div>
				</div>';


	}
 	
 	public function resetForm() {
		$output = sprintf('
				<form name="lostpasswordform" id="lostpasswordform" class="lostpassword-form" action="%s" method="post">
					<p class="lead">%s</p>
					<div class="lostpassword-fields">
					<p class="form-group">
						<label>%s<br />
						<input type="text" name="user_login" class="user_login form-control" value="" size="20" tabindex="10" /></label>
					</p>',
							site_url('wp-login.php?action=lostpassword', 'login_post'),
							__('Reset Password', 'newshopping'),
							__('Username or E-mail:', 'newshopping')
						);

						ob_start();
						do_action('lostpassword_form');

						wp_nonce_field('ajax-pbr-lostpassword-nonce', 'security');
						$output .= ob_get_clean();

						$output .= sprintf('
					<p class="submit">
						<input type="submit" class="btn btn-primary" name="wp-submit" value="%s" tabindex="100" />
						<input type="button" class="btn btn-default btn-cancel" value="%s" tabindex="101" />
					</p>
					<p class="nav">
						',
							__('Get New Password', 'newshopping'),
							__('Cancel', 'newshopping')
							 
							
						);
						$output .= '
					</p>
					</div>
 					<div class="lostpassword-link"><a href="#pbrloginform" class="toggle-links">'.__('Back To Login', 'newshopping').'</a></div>
				</form>';

		return $output;
	}



}

new Newshopping_PBRUserLogin();
?>