<?php

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

class Newshoping_PBR_WooCommerceProductInfoTabs {

	private $tab_data = false;
 
	/** plugin text domain */
	const TEXT_DOMAIN = 'woocommerce-product-info-tabs';

  
	public function __construct() {
		// Installation
		add_action( 'woocommerce_init', array( $this, 'init' ) );
	}
	
 
	public function init() {
		// backend stuff
		add_action( 'woocommerce_product_write_panel_tabs', array( $this, 'product_write_panel_tab' ) );
		add_action( 'woocommerce_product_write_panels',     array( $this, 'product_write_panel' ) );
		add_action( 'woocommerce_process_product_meta',     array( $this, 'product_save_data' ), 10, 2 );

		// frontend stuff
		add_filter( 'woocommerce_product_tabs', array( $this, 'add_custom_product_tabs' ) );

		// allow the use of shortcodes within the tab content
		add_filter( 'woocommerce_custom_product_info_tabs_content', 'do_shortcode' );
	}

 	/**
 	 *
 	 */
	public function add_custom_product_tabs( $tabs ) {
		global $product;

		if ( $this->product_has_custom_tabs( $product ) ) {
			foreach ( $this->tab_data as $tab ) {
				$tab_title =   $tab['title'] ;
				$tabs[ $tab['id'] ] = array(
					'title'    => apply_filters( 'woocommerce_custom_product_info_tabs_title', $tab_title, $product, $this ),
					'priority' => 25,
					'callback' => array( $this, 'custom_product_tabs_panel_content' ),
					'content'  => $tab['content'],  // custom field
				);
			}
		}

		return $tabs;
	}


	/**
 	 *
 	 */ 
	public function custom_product_tabs_panel_content( $key, $tab ) {

		// allow shortcodes to function
		$content = apply_filters( 'the_content', $tab['content'] );
		$content = str_replace( ']]>', ']]&gt;', $content );

		echo apply_filters( 'woocommerce_custom_product_info_tabs_heading', '<h2>' . $tab['title'] . '</h2>', $tab );
		echo apply_filters( 'woocommerce_custom_product_info_tabs_content', $content, $tab );
	}


 	/**
 	 *
 	 */
	public function product_write_panel_tab() {
		echo "<li class=\"product_info_tabs_tab\"><a href=\"#woocommerce_custom_product_info\">" . __( 'Custom Info Tab', 'newshopping') . "</a></li>";
	}

 	/**
 	 *
 	 */
	public function product_write_panel() {
		global $post;
		// the product
		 $postid = isset($_GET['post'] ) ? $_GET['post']: $post->ID;
		// pull the custom tab data out of the database
		$tab_data = maybe_unserialize( get_post_meta( $postid, 'pbr_woo_product_info_tabs', true ) );

		if ( empty( $tab_data ) ) {
			$tab_data[] = array( 'title' => '', 'content' => '' );
		}

		foreach ( $tab_data as $tab ) {
			// display the custom tab panel
			echo '<div id="woocommerce_custom_product_info" class="panel wc-metaboxes-wrapper woocommerce_options_panel">';
			woocommerce_wp_text_input( array( 'id' => '_wc_product_info_tabs_tab_title', 'label' => __( 'Tab Title', 'newshopping'), 'description' => __( 'Required for tab to be visible', 'newshopping'), 'value' => $tab['title'] ) );
			$this->woocommerce_wp_textarea_input( array( 'id' => '_wc_product_info_tabs_tab_content', 'label' => __( 'Content', 'newshopping'), 'placeholder' => __( 'HTML and text to display.', 'newshopping'), 'value' => $tab['content'], 'style' => 'width:70%;height:21.5em;' ) );
			echo '</div>';
		}
	}

 	/**
 	 *
 	 */
	public function product_save_data( $post_id, $post ) {

		$tab_title = stripslashes( $_POST['_wc_product_info_tabs_tab_title'] );
		$tab_content = stripslashes( $_POST['_wc_product_info_tabs_tab_content'] );

		if ( empty( $tab_title ) && empty( $tab_content ) && get_post_meta( $post_id, 'pbr_woo_product_info_tabs', true ) ) {
			// clean up if the custom tabs are removed
			delete_post_meta( $post_id, 'pbr_woo_product_info_tabs' );
		} elseif ( ! empty( $tab_title ) || ! empty( $tab_content ) ) {
			$tab_data = array();

			$tab_id = '';
			if ( $tab_title ) {
				if ( strlen( $tab_title ) != strlen( utf8_encode( $tab_title ) ) ) {
					// can't have titles with utf8 characters as it breaks the tab-switching javascript
					$tab_id = "tab-custom";
				} else {
					// convert the tab title into an id string
					$tab_id = strtolower( $tab_title );
					$tab_id = preg_replace( "/[^\w\s]/", '', $tab_id );
					$tab_id = preg_replace( "/_+/", ' ', $tab_id );
					$tab_id = preg_replace( "/\s+/", '-', $tab_id );
					$tab_id = 'tab-' . $tab_id;
				}
			}

			// save the data to the database
			$tab_data[] = array( 'title' => $tab_title, 'id' => $tab_id, 'content' => $tab_content );
			update_post_meta( $post_id, 'pbr_woo_product_info_tabs', $tab_data );
		}
	}

	/**
 	 *
 	 */
	private function woocommerce_wp_textarea_input( $field ) {
		global $thepostid, $post;
			
		if ( ! $thepostid ) $thepostid = $post->ID;
		if ( ! isset( $field['placeholder'] ) ) $field['placeholder'] = '';
		if ( ! isset( $field['class'] ) ) $field['class'] = 'short';
		if ( ! isset( $field['value'] ) ) $field['value'] = get_post_meta( $thepostid, $field['id'], true );

		echo '<p class="form-field ' . $field['id'] . '_field"><label style="display:block;" for="' . $field['id'] . '">' . $field['label'] . '</label><textarea class="' . $field['class'] . '" name="' . $field['id'] . '" id="' . $field['id'] . '" placeholder="' . $field['placeholder'] . '" rows="2" cols="20"' . (isset( $field['style'] ) ? ' style="' . $field['style'] . '"' : '') . '>' . esc_textarea( $field['value'] ) . '</textarea> ';

		if ( isset( $field['description'] ) && $field['description'] ) {
			echo '<span class="description">' . $field['description'] . '</span>';
		}

		echo '</p>';
	}

 	/**
 	 *
 	 */
	private function product_has_custom_tabs( $product ) {
		if ( false === $this->tab_data ) {
			$this->tab_data = maybe_unserialize( get_post_meta( $product->id, 'pbr_woo_product_info_tabs', true ) );
		}
	
		return ! empty( $this->tab_data ) && ! empty( $this->tab_data[0] ) && ! empty( $this->tab_data[0]['title'] );
	}
}
new Newshoping_PBR_WooCommerceProductInfoTabs();