<?php
/* $Desc
 *
 * @version    $Id$
 * @package    wpbase
 * @author     bigtheme Team <bigtheme@gmail.com, support@bigtheme.ir>
 * @copyright  Copyright (C) 2015 bigtheme.ir. All Rights Reserved.
 * @license    GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 *
 * @website  http://www.bigtheme.ir
 * @support  http://www.bigtheme.ir
 */

if(class_exists('WooCommerce')){

	class Newshoping_PBR_Woocommerce{
		
		public static function getInstance(){
			static $_instance;
			if( !$_instance ){
				$_instance = new Newshoping_PBR_Woocommerce();
			}
			return $_instance;
		}

		public function __construct(){
			if(newshopping_pbr_theme_options('is-quickview',true)){
				// Ajax Quickview
				add_action( 'wp_ajax_pbr_quickview', array($this,'QuickView') );
				add_action( 'wp_ajax_nopriv_pbr_quickview', array($this,'QuickView') );
				add_action( 'wp_footer',array($this,'printFooter') );
			}

			add_action('wp_head',array($this,'initAjaxUrl'),15);

			// Ajax Display Layout
			add_action( 'wp_ajax_pbr_display_layout', array($this,'DisplayLayout') );
			add_action( 'wp_ajax_nopriv_pbr_display_layout', array($this,'DisplayLayout') );

			add_action( 'pbr_button_display',array('Newshoping_PBR_Woocommerce','renderButton'),20 );


 

			if( newshopping_pbr_theme_options( 'is-swap-effect',true ) ){
				remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
				add_action('woocommerce_before_shop_loop_item_title',array($this,'woocommerce_template_loop_product_thumbnail'),10);
			}

			// Change Column number
			add_filter( 'loop_shop_columns', array($this,'wc_loop_shop_columns'), 1, 10 );
			add_filter( 'loop_shop_per_page', array($this,'wc_product_per_page'), 20 );

			// Add Script
			add_action( 'wp_enqueue_scripts',array($this,'initScripts') );
		}

		/**
		 * Initial Ajax Url
		 */
		public function initAjaxUrl() {
		?>
			<script type="text/javascript">
				var ajaxurl = '<?php echo esc_js( admin_url('admin-ajax.php') ); ?>';
			</script>
			<?php
		}
		
		public function initScripts(){
			wp_enqueue_script('PBR_quickview_js', PBR_THEME_URI.'/js/woocommerce.js',array(),false,true);
		}

		public function wc_product_per_page($cols){
			return newshopping_pbr_theme_options('woo-number-page',12);
		}

		public function wc_loop_shop_columns(){
			return newshopping_pbr_theme_options('wc_itemsrow',3);
		}

		public function woocommerce_template_loop_product_thumbnail(){
			global $post, $product, $woocommerce;
			$placeholder_width = get_option('shop_catalog_image_size');
			$placeholder_width = $placeholder_width['width'];

			$placeholder_height = get_option('shop_catalog_image_size');
			$placeholder_height = $placeholder_height['height'];

			$output='';
			$class = 'image-no-effect';
			if(has_post_thumbnail()){
				$attachment_ids = $product->get_gallery_attachment_ids();
				if($attachment_ids) {
					$class = 'image-hover';
					$output.=wp_get_attachment_image($attachment_ids[0],'shop_catalog',false,array('class'=>"attachment-shop_catalog image-effect"));
				}
				$output.=get_the_post_thumbnail( $post->ID,'shop_catalog',array('class'=>$class) );
			}else{
				$output .= '<img src="'.woocommerce_placeholder_img_src().'" alt="'.__('Placeholder' , 'gp_lang').'" class="'.$class.'" width="'.$placeholder_width.'" height="'.$placeholder_height.'" />';
			}
			echo trim($output);
		}


		public static function renderButton(){
			global $wp_query;

			$stringquery = base64_encode(serialize($wp_query->query_vars)) ;
 

            if (isset($_COOKIE['pbr_cookie_layout']) && $_COOKIE['pbr_cookie_layout']=='list') {
                $layout = 'list';
            }else{
                $layout = 'grid';
            }
		?>
		<div class="pull-left">
			<ul class="display">
                <li><span><?php esc_html_e('View','newshopping'); ?></span></li>
                <li>
                	<a style="position:relative;" data-query='<?php echo esc_attr($stringquery); ?>' data-type="list" <?php echo (($layout=='list')?'class="active"':''); ?> href="#">
                		<i class="fa fa-th-list"></i><span><?php esc_html_e('List','newshopping'); ?></span>
                	</a>
                </li>
                <li>
                	<a style="position:relative;" data-query='<?php echo esc_attr($stringquery); ?>' data-type="grid" <?php echo (($layout=='grid')?'class="active"':''); ?> href="#">
            			<i class="fa fa-th"></i><span><?php esc_html_e('Grid','newshopping'); ?></span>
            		</a>
            	</li>
            </ul>
        </div>
		<?php
		}

		public function DisplayLayout(){
			$args = unserialize(base64_decode($_POST['query']));
 
			$type = $_POST['type'];
			$query = new WP_Query($args);
			$this->setCookieDisplay($type);
			while ( $query->have_posts() ) : $query->the_post();
				if($type=='list'){
					wc_get_template_part( 'content', 'product-list' );
				}else{
					wc_get_template_part( 'content', 'product' );
				}
			endwhile;  
			wp_reset_postdata();
			die();
		}

		private function setCookieDisplay($value){
			setcookie('pbr_cookie_layout', $value , time()+3600*24*100,'/');
		}

		public function override_woocommerce_widgets() {
		 
		}

		public function printFooter(){
		?>
			<div class="modal fade" id="pbr_modal_quickview" tabindex="-1" role="dialog" aria-hidden="true">
				<div class="modal-dialog modal-lg">
					<div class="modal-content">
						<div class="modal-header">
							<button type="button" class="close btn btn-close" data-dismiss="modal" aria-hidden="true">
								<i class="fa fa-times"></i>
							</button>
						</div>
						<div class="modal-body"><span class="spinner"></span></div>
					</div>
				</div>
			</div>
		<?php
		}

		public function QuickView(){
			$args = array(
					'post_type'=>'product',
					'product'=>$_GET['productslug']
				);
			$query = new WP_Query($args);
			if($query->have_posts()){
				while($query->have_posts()): $query->the_post(); global $product;
					if(is_file(PBR_THEME_DIR.'/woocommerce/quickview.php')){
						require(PBR_THEME_DIR.'/woocommerce/quickview.php');
					}
				endwhile;
			}
			die;
		}
	}
	Newshoping_PBR_Woocommerce::getInstance();
}